@@ -4,18 +4,18 @@ This library provides a powerful wrapper for multiple Languages and OS. In addit
 
 """
 
-
 from whatstk.whatsapp.objects import WhatsAppChat
 from whatstk.graph import FigureBuilder
-from whatstk.whatsapp.parser import df_from_txt_whatsapp
+from whatstk.whatsapp.parser import df_from_txt_whatsapp, df_from_whatsapp
 
 
 name = "whatstk"
 
-__version__ = "0.6.0"
+__version__ = "0.8.0"
 
 __all__ = [
     "WhatsAppChat",
     "df_from_txt_whatsapp",
+    "df_from_whatsapp",
     "FigureBuilder",
 ]
