@@ -1,9 +1,8 @@
 """Library objects."""
 
-
 from copy import deepcopy
 import pandas as pd
-from typing import Optional, List, Union, Dict, Any
+from typing import Optional, List, Union, Dict, Any, Tuple
 from datetime import datetime
 
 from whatstk.utils.chat_merge import merge_chats
@@ -30,9 +29,28 @@ class BaseChat:
             platform (str): Name of the platform, e.g. 'whatsapp'.
 
         """
-        self._df = df
+        self._df_raw = df
+        self._df, self._df_system, self._name = self._build_dfs(df.copy())
         self._platform = platform
 
+    def _build_dfs(self, df_raw: pd.DataFrame) -> Tuple[pd.DataFrame, pd.DataFrame, str]:
+        if (COLNAMES_DF.MESSAGE_TYPE in df_raw.columns) and self.is_group:
+            mask = df_raw[COLNAMES_DF.MESSAGE_TYPE] == "system"
+            # Get chat only with user messages
+            df = df_raw.loc[~mask].drop(columns=COLNAMES_DF.MESSAGE_TYPE)
+            # Get chat only with system messages
+            df_system = df_raw.loc[mask].drop(columns=COLNAMES_DF.MESSAGE_TYPE)
+            # Get system messages dataframe
+            if len(set(df_system[COLNAMES_DF.USERNAME])) != 1:
+                raise ValueError("System messages dataframe must contain only one username.")
+            chat_name = df_system[COLNAMES_DF.USERNAME].iloc[0]
+            # Drop 'username' from system dataframe
+            df_system = df_system.drop(columns=COLNAMES_DF.USERNAME)
+            return df, df_system, chat_name
+        if (COLNAMES_DF.MESSAGE_TYPE in df_raw.columns) and not self.is_group:
+            df_raw = df_raw.drop(columns=COLNAMES_DF.MESSAGE_TYPE)
+        return df_raw, pd.DataFrame(), ""
+
     @property
     def df(self) -> pd.DataFrame:
         """Chat as DataFrame.
@@ -42,6 +60,29 @@ class BaseChat:
         """
         return self._df
 
+    @property
+    def df_system(self) -> pd.DataFrame:
+        """Chat as DataFrame.
+
+        Returns:
+            pandas.DataFrame
+        """
+        return self._df_system
+
+    @property
+    def is_group(self) -> bool:
+        """True if the chart is a group.
+
+        A chat is detected as a group if it has more than 2 users (including the 'system').
+        Groups with one person will not be detected as groups.
+
+        Returns:
+            bool
+        """
+        if len(set(self._df_raw[COLNAMES_DF.USERNAME])) > 2:
+            return True
+        return False
+
     @property
     def users(self) -> List[str]:
         """List with users.
@@ -51,6 +92,18 @@ class BaseChat:
         """
         return sorted(list(self.df[COLNAMES_DF.USERNAME].unique()))
 
+    @property
+    def name(self) -> Optional[str]:
+        """Name of the chat.
+
+        Returns None if no name could be found. The name is extracted from the username of with
+        the first system message in the chat.
+
+        Returns:
+            list
+        """
+        return self._name
+
     @property
     def start_date(self) -> Union[str, datetime]:
         """Chat starting date.
@@ -59,7 +112,7 @@ class BaseChat:
             datetime
 
         """
-        return self.df[COLNAMES_DF.DATE].min()
+        return self._df_raw[COLNAMES_DF.DATE].min()
 
     @property
     def end_date(self) -> Union[str, datetime]:
@@ -69,10 +122,10 @@ class BaseChat:
             datetime
 
         """
-        return self.df[COLNAMES_DF.DATE].max()
+        return self._df_raw[COLNAMES_DF.DATE].max()
 
     @classmethod
-    def from_source(cls, **kwargs: Dict[str, Any]) -> None:
+    def from_source(cls, **kwargs: Any) -> None:  # noqa: ANN401
         """Load chat.
 
         Args:
@@ -122,8 +175,15 @@ class BaseChat:
                 >>> chat = chat_1.merge(chat_2)
 
         """
+        # Can only merge from same platform
+        if self._platform != chat._platform:
+            raise ValueError("Both chats must come from the same platform.")
+        # Merge
         self_ = deepcopy(self)
+        self_._df_raw = merge_chats([self._df_raw, chat._df_raw])
         self_._df = merge_chats([self.df, chat.df])
+        if (not self.df_system.empty) and (not chat.df_system.empty):
+            self_._df_system = merge_chats([self.df_system, chat.df_system])
         if rename_users:
             self_ = self_.rename_users(mapping=rename_users)
         return self_
@@ -171,6 +231,27 @@ class BaseChat:
                 self_.df[COLNAMES_DF.USERNAME][self_.df[COLNAMES_DF.USERNAME] == old_name] = new_name
         return self_
 
+    def filter_dates(
+        self, date_min: Optional[Union[str, datetime]] = None, date_max: Optional[Union[str, datetime]] = None
+    ) -> "BaseChat":
+        """Filter chat by date range.
+
+        Args:
+            date_min (str, datetime, optional): Minimum date.
+            date_max (str, datetime, optional): Maximum date.
+
+        Returns:
+            BaseChat: Filtered chat.
+
+        """
+        self_ = deepcopy(self)
+        if date_min:
+            self_._df_raw = self_._df_raw[self_._df_raw[COLNAMES_DF.DATE] >= date_min]
+        if date_max:
+            self_._df_raw = self_._df_raw[self_._df_raw[COLNAMES_DF.DATE] <= date_max]
+        self_._df, self_._df_system, self_._name = self_._build_dfs(self_._df_raw.copy())
+        return self_
+
     def to_csv(self, filepath: str) -> None:
         """Save chat as csv.
 
