@@ -10,7 +10,6 @@
         pip install whatstk[gdrive] --upgrade
 """
 
-
 from shutil import copyfile
 import os
 
@@ -19,13 +18,13 @@ try:
     from pydrive2.drive import GoogleDrive
     from pydrive2.files import ApiRequestError
     import yaml
-except ImportError as e:
-    msg = (
+except ImportError as e:  # pragma: no cover
+    msg = (  # pragma: no cover
         "whatstk Google Drive requirements are not installed.\n\n"
         "Please pip install as follows:\n\n"
         '  python -m pip install "whatstk[gdrive]" --upgrade  # or python -m pip install'
-    )
-    raise ImportError(msg) from e
+    )  # pragma: no cover
+    raise ImportError(msg) from e  # pragma: no cover
 
 
 # Create .config/whatstk/gdrive if it does not exist
@@ -101,10 +100,10 @@ def _load_str_from_file_id(file_id: int) -> str:
     try:
         file_obj = drive.CreateFile({"id": file_id})
         file_obj.FetchMetadata()
-    except ApiRequestError:
+    except ApiRequestError as err:
         raise ValueError(
             f"File ID {file_id} not valid. Please use a valid File ID. You can find it in the shareable file link."
-        )
+        ) from err
     # Get raw file content as str
     txt = file_obj.GetContentString()
     return txt
